[Rcpp-commits] r3892 - in pkg/Rcpp: . R

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Sat Nov 3 23:47:42 CET 2012


Author: jjallaire
Date: 2012-11-03 23:47:41 +0100 (Sat, 03 Nov 2012)
New Revision: 3892

Modified:
   pkg/Rcpp/ChangeLog
   pkg/Rcpp/R/Attributes.R
Log:
use CLINK_CPPFLAGS rather than PKG_CXXFLAGS

Modified: pkg/Rcpp/ChangeLog
===================================================================
--- pkg/Rcpp/ChangeLog	2012-11-03 18:41:35 UTC (rev 3891)
+++ pkg/Rcpp/ChangeLog	2012-11-03 22:47:41 UTC (rev 3892)
@@ -1,3 +1,8 @@
+2012-11-03  JJ Allaire <jj at rstudio.org>
+
+        * Use CLINK_CPPFLAGS rather than PKG_CXXFLAGS for LinkingTo 
+        include directories (identical behavior to inline)
+
 2012-11-03  Romain Francois <romain at r-enthusiasts.com>
 
         * include/Rcpp/sugar/functions/which_min.h : sugar which.min

Modified: pkg/Rcpp/R/Attributes.R
===================================================================
--- pkg/Rcpp/R/Attributes.R	2012-11-03 18:41:35 UTC (rev 3891)
+++ pkg/Rcpp/R/Attributes.R	2012-11-03 22:47:41 UTC (rev 3892)
@@ -322,10 +322,8 @@
             buildEnv$PKG_LIBS <- paste(pkgLibs, rcppLibs)
     }
     
-    # set cxxFlags based on the LinkingTo dependencies (and also respect
-    # any PKG_CXXFLAGS set by the plugin)
-    pkgCxxFlags <- .buildPkgCxxFlags(linkingToPackages)
-    buildEnv$PKG_CXXFLAGS <- paste(buildEnv$PKG_CXXFLAGS, pkgCxxFlags)        
+    # set CLINK_CPPFLAGS based on the LinkingTo dependencies
+    buildEnv$CLINK_CPPFLAGS <- .buildClinkCppFlags(linkingToPackages)
 
     # add cygwin message muffler
     buildEnv$CYGWIN = "nodosfilewarning"
@@ -342,8 +340,8 @@
     return (restore)
 }
 
-# Build PKG_CXXFLAGS by from include directories of LinkingTo packages
-.buildPkgCxxFlags <- function(linkingToPackages) {
+# Build CLINK_CPPFLAGS from include directories of LinkingTo packages
+.buildClinkCppFlags <- function(linkingToPackages) {
     pkgCxxFlags <- NULL
     for (package in linkingToPackages) {
         packagePath <- find.package(package, NULL, quiet=TRUE)



More information about the Rcpp-commits mailing list